@@ -21,7 +21,6 @@
 #include <glom/box_withbuttons.h>
 #include <glom/application.h> //Application.
 #include <glom/utils_ui.h>
-#include <gtkmm/stock.h>
 #include <libglom/appstate.h>
 //#include <libgnomeui/gnome-app-helper.h>
 
@@ -31,12 +30,13 @@ namespace Glom
 {
 
 Box_WithButtons::Box_WithButtons()
-: m_Box_Buttons(false, Utils::DEFAULT_SPACING_SMALL),
+: Gtk::Box(Gtk::ORIENTATION_VERTICAL),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
   m_Button_Cancel(Gtk::Stock::CANCEL)
 {
   //m_pDocument = 0;
 
-  set_border_width(Utils::DEFAULT_SPACING_SMALL);
+  //set_border_width(Utils::DEFAULT_SPACING_SMALL);
   set_spacing(Utils::DEFAULT_SPACING_SMALL);
 
   //Connect signals:
@@ -44,13 +44,13 @@ Box_WithButtons::Box_WithButtons()
 }
 
 Box_WithButtons::Box_WithButtons(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
-: Gtk::VBox(cobject),
-  m_Box_Buttons(false, Utils::DEFAULT_SPACING_SMALL),
+: Gtk::Box(cobject),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
   m_Button_Cancel(Gtk::Stock::CANCEL)
 {
   //m_pDocument = 0;
 
-  set_border_width(Utils::DEFAULT_SPACING_SMALL);
+  //set_border_width(Utils::DEFAULT_SPACING_SMALL);
   set_spacing(Utils::DEFAULT_SPACING_SMALL);
 
   //Connect signals:
@@ -58,8 +58,8 @@ Box_WithButtons::Box_WithButtons(BaseObjectType* cobject, const Glib::RefPtr<Gtk
 }
 
 Box_WithButtons::Box_WithButtons(BaseObjectType* cobject)
-: Gtk::VBox(cobject),
-  m_Box_Buttons(false, Utils::DEFAULT_SPACING_SMALL),
+: Gtk::Box(cobject),
+  m_Box_Buttons(Gtk::ORIENTATION_HORIZONTAL, Utils::DEFAULT_SPACING_SMALL),
   m_Button_Cancel(Gtk::Stock::CANCEL)
 {
 }
