@@ -98,6 +98,10 @@ public:
    * Use delete_instance() when the program quits.
    */
   static ConnectionPool* get_instance();
+  
+  /** Whether the connection is ready to be used.
+   */ 
+  static bool get_instance_is_ready();
 
   /** Make the ConnectionPool use the correct backend, with the necessary details,
    * as required by the document.
@@ -128,6 +132,12 @@ public:
 
   Backend* get_backend();
   const Backend* get_backend() const;
+  
+  /** Discover whether the backend can create GdaDataModels that can be iterated,
+   * by creating them with the GDA_STATEMENT_MODEL_CURSOR_FORWARD flag.
+   * If not (with sqlite, for instance), the GdaDataAccessWrapper model can provide that API, without the performance.
+   */
+  bool get_backend_supports_cursor() const;
 
   /** This method will return a SharedConnection, either by opening a new connection or returning an already-open connection.
    * When that SharedConnection is destroyed, or when SharedConnection::close() is called, then the ConnectionPool will be informed.
@@ -289,7 +299,7 @@ private:
   Glib::RefPtr<Gnome::Gda::Connection> m_refGdaConnection;
   guint m_sharedconnection_refcount;
   bool m_ready_to_connect;
-  Glib::ustring m_host, m_user, m_password, m_database;
+  Glib::ustring m_user, m_password, m_database;
 
   FieldTypes* m_pFieldTypes;
   bool m_show_debug_output, m_auto_server_shutdown;
