@@ -277,15 +277,15 @@ void Box_Data_List::on_details_nav_next()
     //Don't go past the last record:
     if( !m_AddDel.get_is_last_row(iter) )
     {
-      std::cout << "debug: " << G_STRFUNC << ": The current row was not the last row." << std::endl;
+      //std::cout << "debug: " << G_STRFUNC << ": The current row was not the last row." << std::endl;
 
       iter++;
       m_AddDel.select_item(iter);
 
       signal_user_requested_details().emit(m_AddDel.get_value_key_selected());
     }
-    else
-      std::cout << "debug: " << G_STRFUNC << ": Not going past the last row." << std::endl;
+    //else
+    //  std::cout << "debug: " << G_STRFUNC << ": Not going past the last row." << std::endl;
   }
 }
 
