@@ -35,7 +35,7 @@ Box_Data_List_Related::Box_Data_List_Related()
   m_Alignment.add(m_AddDel);
   add_view(&m_AddDel); //Give it access to the document.
   m_AddDel.show();
-  m_AddDel.set_height_rows(5);
+  m_AddDel.set_height_rows(6, 6);
   m_Alignment.show();
 
   //Connect signals:
@@ -60,11 +60,9 @@ void Box_Data_List_Related::enable_buttons()
     get_has_suitable_record_to_view_details() &&
     (m_portal->get_navigation_type() != LayoutItem_Portal::NAVIGATION_NONE);
 
-  #ifndef GLOM_ENABLE_MAEMO
   // Don't allow the user to go to a record in a hidden table.
   // Unless we are on Maemo - then we want to allow editing in a separate window only.
   m_AddDel.set_allow_view_details(view_details_possible);
-  #endif //GLOM_ENABLE_MAEMO
 }
 
 bool Box_Data_List_Related::init_db_details(const sharedptr<const LayoutItem_Portal>& portal, bool show_title)
@@ -86,16 +84,11 @@ bool Box_Data_List_Related::init_db_details(const Glib::ustring& parent_table, b
 
   if(show_title)
   {
-    Glib::ustring relationship_title;
-    if(m_portal && m_portal->get_has_relationship_name())
-      relationship_title = m_portal->get_title_used(Glib::ustring() /* parent title - not relevant */);
-    else
-    {
-      //Note to translators: This text is shown instead of a table title, when the table has not yet been chosen.
-      relationship_title = _("Undefined Table");
-    }
+    Glib::ustring title;
+    if(m_portal)
+      title = m_portal->get_title();
 
-    m_Label.set_markup(Utils::bold_message(relationship_title));
+    m_Label.set_markup(Utils::bold_message(title));
     m_Label.show();
 
     m_Alignment.set_padding(Utils::DEFAULT_SPACING_SMALL /* top */, 0, Utils::DEFAULT_SPACING_LARGE /* left */, 0);
@@ -105,7 +98,7 @@ bool Box_Data_List_Related::init_db_details(const Glib::ustring& parent_table, b
     m_Label.set_markup(Glib::ustring());
     m_Label.hide();
 
-    m_Alignment.set_padding(0, 0, 0, 0); //The box itself has padding of 6.
+    m_Alignment.set_padding(0.0f, 0.0f, 0.0f, 0.0f); //The box itself has padding of 6.
   }
 
   if(m_portal)
@@ -175,17 +168,15 @@ Gnome::Gda::Value Box_Data_List_Related::get_primary_key_value(const Gtk::TreeMo
 
 void Box_Data_List_Related::on_adddel_user_requested_edit(const Gtk::TreeModel::iterator& row)
 {
-  if(!(m_portal->get_relationship_used_allows_edit()))
-  {
-    std::cerr << "Box_Data_List_Related::on_adddel_user_requested_eidt() called on non-editable portal. This should not happen." << std::endl;
-    return;
-  }
-
-  //Call base class:
+  //Note that this is really an Open rather than an Edit.
 
   const Gnome::Gda::Value primary_key_value = m_AddDel.get_value_key(row); //The primary key is in the key.
-  //std::cout << "debug: " << G_STRFUNC << ": Requesting edit for primary_key=" << primary_key_value.to_string() << std::endl;
-  signal_user_requested_details().emit(primary_key_value);
+  
+  if(!Conversions::value_is_empty(primary_key_value))
+  {
+    //std::cout << "debug: " << G_STRFUNC << ": Requesting edit for primary_key=" << primary_key_value.to_string() << std::endl;
+    signal_user_requested_details().emit(primary_key_value);
+  }
 }
 
 void Box_Data_List_Related::on_adddel_record_changed()
@@ -393,9 +384,11 @@ void Box_Data_List_Related::create_layout()
   
   if(m_portal)
   {
-    const double rows_count = m_portal->get_rows_count();
-    if(rows_count) //0 is a silly value.
-      m_AddDel.set_height_rows(rows_count);
+    gulong rows_count_min = 0;
+    gulong rows_count_max = 0;
+    m_portal->get_rows_count(rows_count_min, rows_count_max);
+    if(rows_count_min) //0 is a silly value.
+      m_AddDel.set_height_rows(rows_count_min, rows_count_max);
   }
 
   sharedptr<Field> field_primary_key = get_field_primary_key_for_table(Base_DB_Table::m_table_name);
@@ -463,4 +456,10 @@ void Box_Data_List_Related::create_layout()
   m_FieldsShown = get_fields_to_show();
 }
 
+void Box_Data_List_Related::set_find_mode(bool val)
+{
+  Box_Data_Portal::set_find_mode(val);
+  m_AddDel.set_find_mode(val);
+}
+
 } //namespace Glom
