@@ -56,9 +56,21 @@ protected:
    */
   int get_fixed_cell_height(Gtk::Widget& widget);
   
-  typedef Gtk::TreeModelColumn<Glib::ustring> type_model_column_fixed;
-  typedef std::vector< type_model_column_fixed* > type_vec_model_columns_fixed;
-  type_vec_model_columns_fixed m_vec_model_columns_fixed; //If set_choices_fixed() was used.
+
+  typedef Gtk::TreeModelColumn<Glib::ustring> type_model_column_string_fixed;
+  typedef std::vector< type_model_column_string_fixed* > type_vec_model_columns_string_fixed;
+  type_vec_model_columns_string_fixed m_vec_model_columns_string_fixed; //If set_choices_fixed() was used.
+
+  typedef Gtk::TreeModelColumn<Gnome::Gda::Value> type_model_column_value_fixed;
+  typedef std::vector< type_model_column_value_fixed* > type_vec_model_columns_value_fixed;
+  type_vec_model_columns_value_fixed m_vec_model_columns_value_fixed; //If set_choices_fixed() was used.
+
+  /** Get the index of the extra column, at the end, that is just a 
+   * text representation of the first column, for use by GtkCombo with has-entry=true,
+   * which accepts only a text column.
+   */
+  int get_fixed_model_text_column() const;
+
 
   typedef std::vector< sharedptr<const LayoutItem_Field> > type_vec_const_layout_items;
   type_vec_const_layout_items m_db_layout_items; //If set_choices_related() was used.
