@@ -67,9 +67,10 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
         const int cols_count = model.m_data_model_columns_count;
         for(int i = 0; i < cols_count; ++i)
         {
+          //TODO: Use iter->get_value_at(i) with try/catch instead when we can depend on libgdamm >= 4.99.4.2
           Glib::RefPtr<const Gnome::Gda::Holder> holder = iter->get_holder_for_field(i);
           if(holder)
-            m_db_values[i] = holder->get_value(); //TODO_gda: Why not just use get_value_at()?
+            m_db_values[i] = holder->get_value();
           else
           {
             // This is quite possible, for example for unset dates. jhs
@@ -79,6 +80,7 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
           //std::cout << "  debug: col=" << i << ", GType=" << m_db_values[i].get_value_type() << ", string=" << m_db_values[i].to_string() << std::endl;
         }
 
+        //TODO: Use iter->get_value_at(i) with try/catch instead when we can depend on libgdamm >= 4.99.4.2
         Glib::RefPtr<const Gnome::Gda::Holder> holder = iter->get_holder_for_field(model.m_column_index_key);
         if(holder)
           m_key = holder->get_value();  //TODO_gda: Why not just use get_value_at()?
@@ -979,7 +981,7 @@ void DbTreeModel::get_record_counts(gulong& total, gulong& found) const
       {
         if(datamodel->get_n_rows())
         {
-          Gnome::Gda::Value value = datamodel->get_value_at(0, 0);
+          const Gnome::Gda::Value value = datamodel->get_value_at(0, 0);
 	  // This will probably fail on Windows, where a long is only 32 bits wide.
           total = static_cast<gulong>(value.get_int64()); //I discovered that it's a int64 by trying it.
         }
