@@ -18,27 +18,25 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef GLOM_BOX_FORMATTING_H
-#define GLOM_BOX_FORMATTING_H
+#ifndef GLOM_MODE_DESIGN_BOX_FORMATTING_H
+#define GLOM_MODE_DESIGN_BOX_FORMATTING_H
 
-#include <gtkmm/dialog.h>
-#include <gtkmm/radiobutton.h>
-#include <gtkmm/checkbutton.h>
-#include <gtkmm/spinbutton.h>
-#include <gtkmm/colorbutton.h>
-#include <gtkmm/fontbutton.h>
+#include <gtkmm.h>
 #include <glom/utility_widgets/dialog_properties.h>
 #include <libglom/document/document.h>
 #include <glom/box_withbuttons.h>
 #include <glom/mode_design/comboentry_currency.h>
 #include <glom/mode_design/layout/combobox_relationship.h>
 #include <glom/mode_design/layout/combobox_fields.h>
+#include <glom/mode_design/layout/layout_item_dialogs/dialog_fieldslist.h>
 
 namespace Glom
 {
 
+class Dialog_FieldsList;
+
 class Box_Formatting
- : public Gtk::VBox,
+ : public Gtk::Box,
    public View_Composite_Glom
 {
 public:
@@ -51,50 +49,56 @@ public:
   /**
    * @param format The starting information.
    */
-  void set_formatting(const FieldFormatting& format, bool show_numeric = true, bool show_choices = true);
-  
+  void set_formatting_for_non_field(const FieldFormatting& format, bool show_numeric = true);
+
   /**
    * @param format The starting information.
    * @param table_name The field's table.
    * @param The field that will have this formatting, so we know what formatting options to allow.
    */
-  void set_formatting(const FieldFormatting& format, const Glib::ustring& table_name, const sharedptr<const Field>& field);
+  void set_formatting_for_field(const FieldFormatting& format, const Glib::ustring& table_name, const sharedptr<const Field>& field);
   bool get_formatting(FieldFormatting& format) const;
 
-  //When used for print layout items, 
-  //we hide some stuff:
-  void set_is_for_print_layout();
+  /** When used, for instance, for print layout items or choice lists,
+   * where the user could not edit the field anyway.
+   * This hides some UI.
+   */
+  void set_is_for_non_editable();
+
+  typedef sigc::signal<void> type_signal_modified;
+  type_signal_modified signal_modified();
 
 private:
   //Signal handlers:
   void on_combo_choices_relationship_changed();
   void on_checkbox();
+  void on_button_choices_extra();
 
   void enforce_constraints();
 
-  Gtk::VBox* m_vbox_numeric_format;
+  Gtk::Box* m_vbox_numeric_format;
   Gtk::CheckButton* m_checkbox_format_use_thousands;
   Gtk::CheckButton* m_checkbox_format_use_decimal_places;
   Gtk::Entry* m_entry_format_decimal_places;
   ComboEntry_Currency* m_entry_currency_symbol;
   Gtk::CheckButton* m_checkbox_format_color_negatives;
 
-  Gtk::VBox* m_vbox_text_format;
+  Gtk::Box* m_vbox_text_format;
   Gtk::ComboBox* m_combo_format_text_horizontal_alignment;
   Gtk::CheckButton* m_checkbox_format_text_multiline;
   Gtk::Label* m_label_format_text_multiline_height;
   Gtk::SpinButton* m_spinbutton_format_text_multiline_height;
-  Gtk::HBox* m_hbox_font;
+  Gtk::Box* m_hbox_font;
   Gtk::CheckButton* m_checkbox_format_text_font;
   Gtk::FontButton* m_fontbutton;
-  Gtk::HBox* m_hbox_color_foreground;
+  Gtk::Box* m_hbox_color_foreground;
   Gtk::CheckButton* m_checkbox_format_text_color_foreground;
   Gtk::ColorButton* m_colorbutton_foreground;
-  Gtk::HBox* m_hbox_color_background;
+  Gtk::Box* m_hbox_color_background;
   Gtk::CheckButton* m_checkbox_format_text_color_background;
   Gtk::ColorButton* m_colorbutton_background;
 
-  Gtk::VBox* m_vbox_choices;
+  Gtk::Box* m_vbox_choices;
   Gtk::RadioButton* m_radiobutton_choices_custom;
   Gtk::RadioButton* m_radiobutton_choices_related;
   Gtk::CheckButton* m_checkbutton_choices_restricted;
@@ -103,20 +107,25 @@ private:
   guint m_col_index_custom_choices;
   ComboBox_Relationship* m_combo_choices_relationship;
   ComboBox_Fields* m_combo_choices_field;
-  ComboBox_Fields* m_combo_choices_field_second;
+  Gtk::Label* m_label_choices_extra_fields;
+  Gtk::Button* m_button_choices_extra_fields;
   Gtk::CheckButton* m_checkbutton_choices_related_show_all;
 
+  Dialog_FieldsList* m_dialog_choices_extra_fields;
+
   mutable FieldFormatting m_format;
 
   Glib::ustring m_table_name;
   sharedptr<const Field> m_field;
 
-  //We show different options when 
+  //We show different options when
   //showing this on a print layout.
   bool m_for_print_layout;
 
   bool m_show_numeric;
-  bool m_show_choices;
+  bool m_show_editable_options;
+
+  type_signal_modified m_signal_modified;
 
 
   class AlignmentColumns: public Gtk::TreeModelColumnRecord
@@ -135,4 +144,4 @@ private:
 
 } //namespace Glom
 
-#endif //GLOM_BOX_FORMATTING_H
+#endif // GLOM_MODE_DESIGN_BOX_FORMATTING_H
