@@ -31,7 +31,10 @@ namespace Glom
 class Box_Print_Layouts : public Box_DB_Table
 {
 public:
-  Box_Print_Layouts(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  static const char* glade_id;
+  static const bool glade_developer;
+
+  Box_Print_Layouts(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Box_Print_Layouts();
 
 private:
@@ -49,7 +52,6 @@ private:
 
   virtual void on_userlevel_changed(AppState::userlevels userlevel);
 
-  Gtk::Label* m_pLabelFrameTitle;
   guint m_colName;
   guint m_colTitle;
 
