@@ -21,8 +21,8 @@
 #ifndef GLOM_MODE_DESIGN_USERS_DIALOG_NEWSCRIPT_H
 #define GLOM_MODE_DESIGN_USERS_DIALOG_NEWSCRIPT_H
 
-#include <libglademm.h>
 #include <gtkmm/dialog.h>
+#include <gtkmm/builder.h>
 #include <gtkmm/entry.h>
 
 namespace Glom
@@ -31,7 +31,10 @@ namespace Glom
 class Dialog_NewScript : public Gtk::Dialog
 {
 public:
-  Dialog_NewScript(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  static const char* glade_id;
+  static const bool glade_developer;
+
+  Dialog_NewScript(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_NewScript();
 
   Gtk::Entry* m_entry_name;
@@ -40,4 +43,3 @@ public:
 } //namespace Glom
 
 #endif //GLOM_MODE_DESIGN_USERS_DIALOG_NEWSCRIPT_H
-
