@@ -18,12 +18,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <gtkmm.h>
 #include "dialog_change_language.h"
 #include <glibmm/i18n.h>
 
 namespace Glom
 {
 
+const char* Dialog_ChangeLanguage::glade_id("dialog_change_language");
+const bool Dialog_ChangeLanguage::glade_developer(true);
+
 Dialog_ChangeLanguage::Dialog_ChangeLanguage(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
   m_combo_locale(0)
