@@ -17,9 +17,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <gtkmm/builder.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/main.h>
+#include <gtkmm.h>
 #include <gtksourceviewmm/init.h>
 #include <libxml++/libxml++.h>
 
@@ -91,7 +89,7 @@ static bool attempt_instantiation(const std::string& filepath, const xmlpp::Elem
 int main(int argc, char* argv[])
 {
   Gtk::Main kit(argc, argv);
-  gtksourceview::init(); //Our .glade files contain gtksourceview widgets too.
+  Gsv::init(); //Our .glade files contain gtksourceview widgets too.
 
   std::string filepath;
   if(argc > 1 )
