@@ -1,9 +1,7 @@
-#include <gtkmm.h>
 #include <glom/import_csv/csv_parser.h>
 #include <tests/import/utils.h>
-#include <giomm/file.h>
-#include <glibmm/init.h>
-#include <giomm/init.h>
+#include <glibmm.h>
+#include <giomm.h>
 #include <iostream>
 #include <stdexcept>
 #include <cstdlib>
@@ -40,11 +38,13 @@ void reset_signal_counts()
   get_encoding_error_count_instance() = 0;
 }
 
+/*
 void print_signal_counts()
 {
   std::cout << "lines scanned: " << get_line_scanned_count_instance() << std::endl;
   std::cout << "encoding errors: " << get_encoding_error_count_instance() << std::endl;
 }
+*/
 
 void connect_signals(Glom::CsvParser& parser)
 {
@@ -55,15 +55,11 @@ void connect_signals(Glom::CsvParser& parser)
 } // namespace
 
 // Testcases
-int main(int argc, char* argv[])
+int main()
 {
-  //Threading is always enabled starting from GLib 2.31.0:
-  //TODO: Just remove this when we can increase the glibmm version needed:
-#if !GLIB_CHECK_VERSION (2, 31, 0)
   Glib::thread_init();
-#endif
-
-  Gtk::Main gtk(argc, argv);
+  Glib::init();
+  Gio::init();
 
   bool result = true;
   std::stringstream report;
@@ -114,7 +110,6 @@ int main(int argc, char* argv[])
          iter != encodings.end();
          ++iter)
     {
-      #ifdef GLIBMM_EXCEPTIONS_ENABLED
       try
       {
         while(parser.on_idle_parse())
@@ -126,12 +121,6 @@ int main(int argc, char* argv[])
       {
         std::cout << exception.what() << std::endl;
       }
-      #else
-      while(parser.on_idle_parse())
-      {}
-
-      parser.clear();
-      #endif
 
       parser.set_encoding((*iter).c_str());
     }
